@@ -10,7 +10,7 @@ def drop_privileges (uid_name = None):
         return
 
     import pwd, grp
-    user_name = os.getenv("SUDO_USER") or uid_name or 'nobody'
+    user_name = uid_name or os.getenv("SUDO_USER") or 'nobody'
     pwnam = pwd.getpwnam(user_name)
     os.setgroups([])
     os.setgid(pwnam.pw_gid)
